@@ -21,9 +21,9 @@ To make a I<PAR distribution> from a CPAN module distribution:
 
 To manipulate a I<PAR distribution>:
 
-    % par.pl -i Foo-0.01-i386-freebsd-5.8.0.par	# install
-    % par.pl -i http://foo.com/Foo-0.01		# auto-appends archname + perlver
-    % par.pl -i cpan://AUTRIJUS/PAR-0.74	# uses CPAN author directory
+    % par.pl -i Foo-0.01-i386-freebsd-5.8.0.par # install
+    % par.pl -i http://foo.com/Foo-0.01         # auto-appends archname + perlver
+    % par.pl -i cpan://AUTRIJUS/PAR-0.74        # uses CPAN author directory
     % par.pl -u Foo-0.01-i386-freebsd-5.8.0.par # uninstall
     % par.pl -s Foo-0.01-i386-freebsd-5.8.0.par # sign
     % par.pl -v Foo-0.01-i386-freebsd-5.8.0.par # verify
@@ -159,7 +159,7 @@ END { if ($ENV{PAR_CLEAN}) {
 BEGIN {
     Internals::PAR::BOOT() if defined &Internals::PAR::BOOT;
 
-    eval {
+    do {
 
 _par_init_env();
 
@@ -306,7 +306,7 @@ my ($start_pos, $data_pos);
 
     # load rest of the group in
     while (my $filename = (sort keys %require_list)[0]) {
-        local $INC{'Cwd.pm'} = __FILE__;
+        local $INC{'Cwd.pm'} = __FILE__ if $^O ne 'MSWin32';
         require $filename unless $INC{$filename} or $filename =~ /BSDPAN/;
         delete $require_list{$filename};
     }
@@ -384,7 +384,7 @@ if (!$start_pos or ($ARGV[0] eq '--par-options' && shift)) {
 # Output mode (-O) handling {{{
 if ($out) {
     {
-        local $INC{'Cwd.pm'} = __FILE__;
+        local $INC{'Cwd.pm'} = __FILE__ if $^O ne 'MSWin32';
         require IO::File;
         require Archive::Zip;
     }
@@ -423,9 +423,9 @@ if ($out) {
     }
 
     my $fh = IO::File->new(
-	$out,
-	IO::File::O_CREAT() | IO::File::O_WRONLY() | IO::File::O_TRUNC(),
-	0777,
+        $out,
+        IO::File::O_CREAT() | IO::File::O_WRONLY() | IO::File::O_TRUNC(),
+        0777,
     ) or die $!;
     binmode($fh);
 
@@ -578,7 +578,7 @@ if ($out) {
 
 
     {
-        local $INC{'Cwd.pm'} = __FILE__;
+        local $INC{'Cwd.pm'} = __FILE__ if $^O ne 'MSWin32';
         require File::Find;
         require Archive::Zip;
     }
@@ -624,7 +624,7 @@ Usage: $0 [ -Alib.par ] [ -Idir ] [ -Mmodule ] [ src.par ] [ program.pl ]
 # }}}
 
 sub require_modules {
-    local $INC{'Cwd.pm'} = __FILE__;
+    local $INC{'Cwd.pm'} = __FILE__ if $^O ne 'MSWin32';
 
     require lib;
     require DynaLoader;
@@ -763,6 +763,11 @@ sub _fix_progname {
     if (index($progname, $Config{_delim}) < 0) {
         $progname = ".$Config{_delim}$progname";
     }
+
+    # XXX - hack to make PWD work
+    my $pwd = (defined &Win32::GetCwd) ? Win32::GetCwd() : $ENV{PWD};
+    $progname =~ s/^(?=\.\.?\Q$Config{_delim}\E)/$pwd$Config{_delim}/;
+
     $ENV{PAR_PROGNAME} = $progname;
 }
 
@@ -853,7 +858,8 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2002, 2003, 2004 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2002, 2003, 2004, 2005 by Autrijus Tang
+E<lt>autrijus@autrijus.orgE<gt>.
 
 Neither this program nor the associated L<parl> program impose any
 licensing restrictions on files generated by their execution, in
